# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: zeebe_grpc/gateway.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='zeebe_grpc/gateway.proto',
  package='gateway_protocol',
  syntax='proto3',
  serialized_options=b'\n!io.camunda.zeebe.gateway.protocolP\000Z\005./;pb',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x18zeebe_grpc/gateway.proto\x12\x10gateway_protocol\"\x8e\x01\n\x13\x41\x63tivateJobsRequest\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06worker\x18\x02 \x01(\t\x12\x0f\n\x07timeout\x18\x03 \x01(\x03\x12\x19\n\x11maxJobsToActivate\x18\x04 \x01(\x05\x12\x15\n\rfetchVariable\x18\x05 \x03(\t\x12\x16\n\x0erequestTimeout\x18\x06 \x01(\x03\"D\n\x14\x41\x63tivateJobsResponse\x12,\n\x04jobs\x18\x01 \x03(\x0b\x32\x1e.gateway_protocol.ActivatedJob\"\xa8\x02\n\x0c\x41\x63tivatedJob\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x1a\n\x12processInstanceKey\x18\x03 \x01(\x03\x12\x15\n\rbpmnProcessId\x18\x04 \x01(\t\x12 \n\x18processDefinitionVersion\x18\x05 \x01(\x05\x12\x1c\n\x14processDefinitionKey\x18\x06 \x01(\x03\x12\x11\n\telementId\x18\x07 \x01(\t\x12\x1a\n\x12\x65lementInstanceKey\x18\x08 \x01(\x03\x12\x15\n\rcustomHeaders\x18\t \x01(\t\x12\x0e\n\x06worker\x18\n \x01(\t\x12\x0f\n\x07retries\x18\x0b \x01(\x05\x12\x10\n\x08\x64\x65\x61\x64line\x18\x0c \x01(\x03\x12\x11\n\tvariables\x18\r \x01(\t\":\n\x1c\x43\x61ncelProcessInstanceRequest\x12\x1a\n\x12processInstanceKey\x18\x01 \x01(\x03\"\x1f\n\x1d\x43\x61ncelProcessInstanceResponse\"7\n\x12\x43ompleteJobRequest\x12\x0e\n\x06jobKey\x18\x01 \x01(\x03\x12\x11\n\tvariables\x18\x02 \x01(\t\"\x15\n\x13\x43ompleteJobResponse\"w\n\x1c\x43reateProcessInstanceRequest\x12\x1c\n\x14processDefinitionKey\x18\x01 \x01(\x03\x12\x15\n\rbpmnProcessId\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\x05\x12\x11\n\tvariables\x18\x04 \x01(\t\"\x81\x01\n\x1d\x43reateProcessInstanceResponse\x12\x1c\n\x14processDefinitionKey\x18\x01 \x01(\x03\x12\x15\n\rbpmnProcessId\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\x05\x12\x1a\n\x12processInstanceKey\x18\x04 \x01(\x03\"\x99\x01\n&CreateProcessInstanceWithResultRequest\x12?\n\x07request\x18\x01 \x01(\x0b\x32..gateway_protocol.CreateProcessInstanceRequest\x12\x16\n\x0erequestTimeout\x18\x02 \x01(\x03\x12\x16\n\x0e\x66\x65tchVariables\x18\x03 \x03(\t\"\x9e\x01\n\'CreateProcessInstanceWithResultResponse\x12\x1c\n\x14processDefinitionKey\x18\x01 \x01(\x03\x12\x15\n\rbpmnProcessId\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\x05\x12\x1a\n\x12processInstanceKey\x18\x04 \x01(\x03\x12\x11\n\tvariables\x18\x05 \x01(\t\"Q\n\x14\x44\x65ployProcessRequest\x12\x39\n\tprocesses\x18\x01 \x03(\x0b\x32&.gateway_protocol.ProcessRequestObject\"8\n\x14ProcessRequestObject\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ndefinition\x18\x02 \x01(\x0c\"Z\n\x15\x44\x65ployProcessResponse\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\x34\n\tprocesses\x18\x02 \x03(\x0b\x32!.gateway_protocol.ProcessMetadata\"m\n\x0fProcessMetadata\x12\x15\n\rbpmnProcessId\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\x05\x12\x1c\n\x14processDefinitionKey\x18\x03 \x01(\x03\x12\x14\n\x0cresourceName\x18\x04 \x01(\t\"]\n\x0e\x46\x61ilJobRequest\x12\x0e\n\x06jobKey\x18\x01 \x01(\x03\x12\x0f\n\x07retries\x18\x02 \x01(\x05\x12\x14\n\x0c\x65rrorMessage\x18\x03 \x01(\t\x12\x14\n\x0cretryBackOff\x18\x04 \x01(\x03\"\x11\n\x0f\x46\x61ilJobResponse\"L\n\x11ThrowErrorRequest\x12\x0e\n\x06jobKey\x18\x01 \x01(\x03\x12\x11\n\terrorCode\x18\x02 \x01(\t\x12\x14\n\x0c\x65rrorMessage\x18\x03 \x01(\t\"\x14\n\x12ThrowErrorResponse\"w\n\x15PublishMessageRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x16\n\x0e\x63orrelationKey\x18\x02 \x01(\t\x12\x12\n\ntimeToLive\x18\x03 \x01(\x03\x12\x11\n\tmessageId\x18\x04 \x01(\t\x12\x11\n\tvariables\x18\x05 \x01(\t\"%\n\x16PublishMessageResponse\x12\x0b\n\x03key\x18\x01 \x01(\x03\"-\n\x16ResolveIncidentRequest\x12\x13\n\x0bincidentKey\x18\x01 \x01(\x03\"\x19\n\x17ResolveIncidentResponse\"\x11\n\x0fTopologyRequest\"\xa2\x01\n\x10TopologyResponse\x12-\n\x07\x62rokers\x18\x01 \x03(\x0b\x32\x1c.gateway_protocol.BrokerInfo\x12\x13\n\x0b\x63lusterSize\x18\x02 \x01(\x05\x12\x17\n\x0fpartitionsCount\x18\x03 \x01(\x05\x12\x19\n\x11replicationFactor\x18\x04 \x01(\x05\x12\x16\n\x0egatewayVersion\x18\x05 \x01(\t\"z\n\nBrokerInfo\x12\x0e\n\x06nodeId\x18\x01 \x01(\x05\x12\x0c\n\x04host\x18\x02 \x01(\t\x12\x0c\n\x04port\x18\x03 \x01(\x05\x12/\n\npartitions\x18\x04 \x03(\x0b\x32\x1b.gateway_protocol.Partition\x12\x0f\n\x07version\x18\x05 \x01(\t\"\xa0\x02\n\tPartition\x12\x13\n\x0bpartitionId\x18\x01 \x01(\x05\x12=\n\x04role\x18\x02 \x01(\x0e\x32/.gateway_protocol.Partition.PartitionBrokerRole\x12\x41\n\x06health\x18\x03 \x01(\x0e\x32\x31.gateway_protocol.Partition.PartitionBrokerHealth\"=\n\x13PartitionBrokerRole\x12\n\n\x06LEADER\x10\x00\x12\x0c\n\x08\x46OLLOWER\x10\x01\x12\x0c\n\x08INACTIVE\x10\x02\"=\n\x15PartitionBrokerHealth\x12\x0b\n\x07HEALTHY\x10\x00\x12\r\n\tUNHEALTHY\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\":\n\x17UpdateJobRetriesRequest\x12\x0e\n\x06jobKey\x18\x01 \x01(\x03\x12\x0f\n\x07retries\x18\x02 \x01(\x05\"\x1a\n\x18UpdateJobRetriesResponse\"S\n\x13SetVariablesRequest\x12\x1a\n\x12\x65lementInstanceKey\x18\x01 \x01(\x03\x12\x11\n\tvariables\x18\x02 \x01(\t\x12\r\n\x05local\x18\x03 \x01(\x08\"#\n\x14SetVariablesResponse\x12\x0b\n\x03key\x18\x01 \x01(\x03\x32\xe2\n\n\x07Gateway\x12\x61\n\x0c\x41\x63tivateJobs\x12%.gateway_protocol.ActivateJobsRequest\x1a&.gateway_protocol.ActivateJobsResponse\"\x00\x30\x01\x12z\n\x15\x43\x61ncelProcessInstance\x12..gateway_protocol.CancelProcessInstanceRequest\x1a/.gateway_protocol.CancelProcessInstanceResponse\"\x00\x12\\\n\x0b\x43ompleteJob\x12$.gateway_protocol.CompleteJobRequest\x1a%.gateway_protocol.CompleteJobResponse\"\x00\x12z\n\x15\x43reateProcessInstance\x12..gateway_protocol.CreateProcessInstanceRequest\x1a/.gateway_protocol.CreateProcessInstanceResponse\"\x00\x12\x98\x01\n\x1f\x43reateProcessInstanceWithResult\x12\x38.gateway_protocol.CreateProcessInstanceWithResultRequest\x1a\x39.gateway_protocol.CreateProcessInstanceWithResultResponse\"\x00\x12\x62\n\rDeployProcess\x12&.gateway_protocol.DeployProcessRequest\x1a\'.gateway_protocol.DeployProcessResponse\"\x00\x12P\n\x07\x46\x61ilJob\x12 .gateway_protocol.FailJobRequest\x1a!.gateway_protocol.FailJobResponse\"\x00\x12Y\n\nThrowError\x12#.gateway_protocol.ThrowErrorRequest\x1a$.gateway_protocol.ThrowErrorResponse\"\x00\x12\x65\n\x0ePublishMessage\x12\'.gateway_protocol.PublishMessageRequest\x1a(.gateway_protocol.PublishMessageResponse\"\x00\x12h\n\x0fResolveIncident\x12(.gateway_protocol.ResolveIncidentRequest\x1a).gateway_protocol.ResolveIncidentResponse\"\x00\x12_\n\x0cSetVariables\x12%.gateway_protocol.SetVariablesRequest\x1a&.gateway_protocol.SetVariablesResponse\"\x00\x12S\n\x08Topology\x12!.gateway_protocol.TopologyRequest\x1a\".gateway_protocol.TopologyResponse\"\x00\x12k\n\x10UpdateJobRetries\x12).gateway_protocol.UpdateJobRetriesRequest\x1a*.gateway_protocol.UpdateJobRetriesResponse\"\x00\x42,\n!io.camunda.zeebe.gateway.protocolP\x00Z\x05./;pbb\x06proto3'
)



_PARTITION_PARTITIONBROKERROLE = _descriptor.EnumDescriptor(
  name='PartitionBrokerRole',
  full_name='gateway_protocol.Partition.PartitionBrokerRole',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LEADER', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FOLLOWER', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INACTIVE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2568,
  serialized_end=2629,
)
_sym_db.RegisterEnumDescriptor(_PARTITION_PARTITIONBROKERROLE)

_PARTITION_PARTITIONBROKERHEALTH = _descriptor.EnumDescriptor(
  name='PartitionBrokerHealth',
  full_name='gateway_protocol.Partition.PartitionBrokerHealth',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='HEALTHY', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNHEALTHY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEAD', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2631,
  serialized_end=2692,
)
_sym_db.RegisterEnumDescriptor(_PARTITION_PARTITIONBROKERHEALTH)


_ACTIVATEJOBSREQUEST = _descriptor.Descriptor(
  name='ActivateJobsRequest',
  full_name='gateway_protocol.ActivateJobsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='gateway_protocol.ActivateJobsRequest.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='worker', full_name='gateway_protocol.ActivateJobsRequest.worker', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='gateway_protocol.ActivateJobsRequest.timeout', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maxJobsToActivate', full_name='gateway_protocol.ActivateJobsRequest.maxJobsToActivate', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fetchVariable', full_name='gateway_protocol.ActivateJobsRequest.fetchVariable', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='requestTimeout', full_name='gateway_protocol.ActivateJobsRequest.requestTimeout', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=47,
  serialized_end=189,
)


_ACTIVATEJOBSRESPONSE = _descriptor.Descriptor(
  name='ActivateJobsResponse',
  full_name='gateway_protocol.ActivateJobsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobs', full_name='gateway_protocol.ActivateJobsResponse.jobs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=191,
  serialized_end=259,
)


_ACTIVATEDJOB = _descriptor.Descriptor(
  name='ActivatedJob',
  full_name='gateway_protocol.ActivatedJob',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='gateway_protocol.ActivatedJob.key', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='gateway_protocol.ActivatedJob.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='processInstanceKey', full_name='gateway_protocol.ActivatedJob.processInstanceKey', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bpmnProcessId', full_name='gateway_protocol.ActivatedJob.bpmnProcessId', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='processDefinitionVersion', full_name='gateway_protocol.ActivatedJob.processDefinitionVersion', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='processDefinitionKey', full_name='gateway_protocol.ActivatedJob.processDefinitionKey', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='elementId', full_name='gateway_protocol.ActivatedJob.elementId', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='elementInstanceKey', full_name='gateway_protocol.ActivatedJob.elementInstanceKey', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customHeaders', full_name='gateway_protocol.ActivatedJob.customHeaders', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='worker', full_name='gateway_protocol.ActivatedJob.worker', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retries', full_name='gateway_protocol.ActivatedJob.retries', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deadline', full_name='gateway_protocol.ActivatedJob.deadline', index=11,
      number=12, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='variables', full_name='gateway_protocol.ActivatedJob.variables', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=262,
  serialized_end=558,
)


_CANCELPROCESSINSTANCEREQUEST = _descriptor.Descriptor(
  name='CancelProcessInstanceRequest',
  full_name='gateway_protocol.CancelProcessInstanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='processInstanceKey', full_name='gateway_protocol.CancelProcessInstanceRequest.processInstanceKey', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=560,
  serialized_end=618,
)


_CANCELPROCESSINSTANCERESPONSE = _descriptor.Descriptor(
  name='CancelProcessInstanceResponse',
  full_name='gateway_protocol.CancelProcessInstanceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=620,
  serialized_end=651,
)


_COMPLETEJOBREQUEST = _descriptor.Descriptor(
  name='CompleteJobRequest',
  full_name='gateway_protocol.CompleteJobRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobKey', full_name='gateway_protocol.CompleteJobRequest.jobKey', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='variables', full_name='gateway_protocol.CompleteJobRequest.variables', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=653,
  serialized_end=708,
)


_COMPLETEJOBRESPONSE = _descriptor.Descriptor(
  name='CompleteJobResponse',
  full_name='gateway_protocol.CompleteJobResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=710,
  serialized_end=731,
)


_CREATEPROCESSINSTANCEREQUEST = _descriptor.Descriptor(
  name='CreateProcessInstanceRequest',
  full_name='gateway_protocol.CreateProcessInstanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='processDefinitionKey', full_name='gateway_protocol.CreateProcessInstanceRequest.processDefinitionKey', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bpmnProcessId', full_name='gateway_protocol.CreateProcessInstanceRequest.bpmnProcessId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='gateway_protocol.CreateProcessInstanceRequest.version', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='variables', full_name='gateway_protocol.CreateProcessInstanceRequest.variables', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=733,
  serialized_end=852,
)


_CREATEPROCESSINSTANCERESPONSE = _descriptor.Descriptor(
  name='CreateProcessInstanceResponse',
  full_name='gateway_protocol.CreateProcessInstanceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='processDefinitionKey', full_name='gateway_protocol.CreateProcessInstanceResponse.processDefinitionKey', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bpmnProcessId', full_name='gateway_protocol.CreateProcessInstanceResponse.bpmnProcessId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='gateway_protocol.CreateProcessInstanceResponse.version', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='processInstanceKey', full_name='gateway_protocol.CreateProcessInstanceResponse.processInstanceKey', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=855,
  serialized_end=984,
)


_CREATEPROCESSINSTANCEWITHRESULTREQUEST = _descriptor.Descriptor(
  name='CreateProcessInstanceWithResultRequest',
  full_name='gateway_protocol.CreateProcessInstanceWithResultRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='gateway_protocol.CreateProcessInstanceWithResultRequest.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='requestTimeout', full_name='gateway_protocol.CreateProcessInstanceWithResultRequest.requestTimeout', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fetchVariables', full_name='gateway_protocol.CreateProcessInstanceWithResultRequest.fetchVariables', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=987,
  serialized_end=1140,
)


_CREATEPROCESSINSTANCEWITHRESULTRESPONSE = _descriptor.Descriptor(
  name='CreateProcessInstanceWithResultResponse',
  full_name='gateway_protocol.CreateProcessInstanceWithResultResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='processDefinitionKey', full_name='gateway_protocol.CreateProcessInstanceWithResultResponse.processDefinitionKey', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bpmnProcessId', full_name='gateway_protocol.CreateProcessInstanceWithResultResponse.bpmnProcessId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='gateway_protocol.CreateProcessInstanceWithResultResponse.version', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='processInstanceKey', full_name='gateway_protocol.CreateProcessInstanceWithResultResponse.processInstanceKey', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='variables', full_name='gateway_protocol.CreateProcessInstanceWithResultResponse.variables', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1143,
  serialized_end=1301,
)


_DEPLOYPROCESSREQUEST = _descriptor.Descriptor(
  name='DeployProcessRequest',
  full_name='gateway_protocol.DeployProcessRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='processes', full_name='gateway_protocol.DeployProcessRequest.processes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1303,
  serialized_end=1384,
)


_PROCESSREQUESTOBJECT = _descriptor.Descriptor(
  name='ProcessRequestObject',
  full_name='gateway_protocol.ProcessRequestObject',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway_protocol.ProcessRequestObject.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='definition', full_name='gateway_protocol.ProcessRequestObject.definition', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1386,
  serialized_end=1442,
)


_DEPLOYPROCESSRESPONSE = _descriptor.Descriptor(
  name='DeployProcessResponse',
  full_name='gateway_protocol.DeployProcessResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='gateway_protocol.DeployProcessResponse.key', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='processes', full_name='gateway_protocol.DeployProcessResponse.processes', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1444,
  serialized_end=1534,
)


_PROCESSMETADATA = _descriptor.Descriptor(
  name='ProcessMetadata',
  full_name='gateway_protocol.ProcessMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bpmnProcessId', full_name='gateway_protocol.ProcessMetadata.bpmnProcessId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='gateway_protocol.ProcessMetadata.version', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='processDefinitionKey', full_name='gateway_protocol.ProcessMetadata.processDefinitionKey', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resourceName', full_name='gateway_protocol.ProcessMetadata.resourceName', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1536,
  serialized_end=1645,
)


_FAILJOBREQUEST = _descriptor.Descriptor(
  name='FailJobRequest',
  full_name='gateway_protocol.FailJobRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobKey', full_name='gateway_protocol.FailJobRequest.jobKey', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retries', full_name='gateway_protocol.FailJobRequest.retries', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='errorMessage', full_name='gateway_protocol.FailJobRequest.errorMessage', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retryBackOff', full_name='gateway_protocol.FailJobRequest.retryBackOff', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1647,
  serialized_end=1740,
)


_FAILJOBRESPONSE = _descriptor.Descriptor(
  name='FailJobResponse',
  full_name='gateway_protocol.FailJobResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1742,
  serialized_end=1759,
)


_THROWERRORREQUEST = _descriptor.Descriptor(
  name='ThrowErrorRequest',
  full_name='gateway_protocol.ThrowErrorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobKey', full_name='gateway_protocol.ThrowErrorRequest.jobKey', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='errorCode', full_name='gateway_protocol.ThrowErrorRequest.errorCode', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='errorMessage', full_name='gateway_protocol.ThrowErrorRequest.errorMessage', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1761,
  serialized_end=1837,
)


_THROWERRORRESPONSE = _descriptor.Descriptor(
  name='ThrowErrorResponse',
  full_name='gateway_protocol.ThrowErrorResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1839,
  serialized_end=1859,
)


_PUBLISHMESSAGEREQUEST = _descriptor.Descriptor(
  name='PublishMessageRequest',
  full_name='gateway_protocol.PublishMessageRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway_protocol.PublishMessageRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='correlationKey', full_name='gateway_protocol.PublishMessageRequest.correlationKey', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeToLive', full_name='gateway_protocol.PublishMessageRequest.timeToLive', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='messageId', full_name='gateway_protocol.PublishMessageRequest.messageId', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='variables', full_name='gateway_protocol.PublishMessageRequest.variables', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1861,
  serialized_end=1980,
)


_PUBLISHMESSAGERESPONSE = _descriptor.Descriptor(
  name='PublishMessageResponse',
  full_name='gateway_protocol.PublishMessageResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='gateway_protocol.PublishMessageResponse.key', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1982,
  serialized_end=2019,
)


_RESOLVEINCIDENTREQUEST = _descriptor.Descriptor(
  name='ResolveIncidentRequest',
  full_name='gateway_protocol.ResolveIncidentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='incidentKey', full_name='gateway_protocol.ResolveIncidentRequest.incidentKey', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2021,
  serialized_end=2066,
)


_RESOLVEINCIDENTRESPONSE = _descriptor.Descriptor(
  name='ResolveIncidentResponse',
  full_name='gateway_protocol.ResolveIncidentResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2068,
  serialized_end=2093,
)


_TOPOLOGYREQUEST = _descriptor.Descriptor(
  name='TopologyRequest',
  full_name='gateway_protocol.TopologyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2095,
  serialized_end=2112,
)


_TOPOLOGYRESPONSE = _descriptor.Descriptor(
  name='TopologyResponse',
  full_name='gateway_protocol.TopologyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='brokers', full_name='gateway_protocol.TopologyResponse.brokers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clusterSize', full_name='gateway_protocol.TopologyResponse.clusterSize', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partitionsCount', full_name='gateway_protocol.TopologyResponse.partitionsCount', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='replicationFactor', full_name='gateway_protocol.TopologyResponse.replicationFactor', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gatewayVersion', full_name='gateway_protocol.TopologyResponse.gatewayVersion', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2115,
  serialized_end=2277,
)


_BROKERINFO = _descriptor.Descriptor(
  name='BrokerInfo',
  full_name='gateway_protocol.BrokerInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='nodeId', full_name='gateway_protocol.BrokerInfo.nodeId', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host', full_name='gateway_protocol.BrokerInfo.host', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='gateway_protocol.BrokerInfo.port', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partitions', full_name='gateway_protocol.BrokerInfo.partitions', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='gateway_protocol.BrokerInfo.version', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2279,
  serialized_end=2401,
)


_PARTITION = _descriptor.Descriptor(
  name='Partition',
  full_name='gateway_protocol.Partition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='partitionId', full_name='gateway_protocol.Partition.partitionId', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='role', full_name='gateway_protocol.Partition.role', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='health', full_name='gateway_protocol.Partition.health', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PARTITION_PARTITIONBROKERROLE,
    _PARTITION_PARTITIONBROKERHEALTH,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2404,
  serialized_end=2692,
)


_UPDATEJOBRETRIESREQUEST = _descriptor.Descriptor(
  name='UpdateJobRetriesRequest',
  full_name='gateway_protocol.UpdateJobRetriesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobKey', full_name='gateway_protocol.UpdateJobRetriesRequest.jobKey', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retries', full_name='gateway_protocol.UpdateJobRetriesRequest.retries', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2694,
  serialized_end=2752,
)


_UPDATEJOBRETRIESRESPONSE = _descriptor.Descriptor(
  name='UpdateJobRetriesResponse',
  full_name='gateway_protocol.UpdateJobRetriesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2754,
  serialized_end=2780,
)


_SETVARIABLESREQUEST = _descriptor.Descriptor(
  name='SetVariablesRequest',
  full_name='gateway_protocol.SetVariablesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='elementInstanceKey', full_name='gateway_protocol.SetVariablesRequest.elementInstanceKey', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='variables', full_name='gateway_protocol.SetVariablesRequest.variables', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='local', full_name='gateway_protocol.SetVariablesRequest.local', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2782,
  serialized_end=2865,
)


_SETVARIABLESRESPONSE = _descriptor.Descriptor(
  name='SetVariablesResponse',
  full_name='gateway_protocol.SetVariablesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='gateway_protocol.SetVariablesResponse.key', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2867,
  serialized_end=2902,
)

_ACTIVATEJOBSRESPONSE.fields_by_name['jobs'].message_type = _ACTIVATEDJOB
_CREATEPROCESSINSTANCEWITHRESULTREQUEST.fields_by_name['request'].message_type = _CREATEPROCESSINSTANCEREQUEST
_DEPLOYPROCESSREQUEST.fields_by_name['processes'].message_type = _PROCESSREQUESTOBJECT
_DEPLOYPROCESSRESPONSE.fields_by_name['processes'].message_type = _PROCESSMETADATA
_TOPOLOGYRESPONSE.fields_by_name['brokers'].message_type = _BROKERINFO
_BROKERINFO.fields_by_name['partitions'].message_type = _PARTITION
_PARTITION.fields_by_name['role'].enum_type = _PARTITION_PARTITIONBROKERROLE
_PARTITION.fields_by_name['health'].enum_type = _PARTITION_PARTITIONBROKERHEALTH
_PARTITION_PARTITIONBROKERROLE.containing_type = _PARTITION
_PARTITION_PARTITIONBROKERHEALTH.containing_type = _PARTITION
DESCRIPTOR.message_types_by_name['ActivateJobsRequest'] = _ACTIVATEJOBSREQUEST
DESCRIPTOR.message_types_by_name['ActivateJobsResponse'] = _ACTIVATEJOBSRESPONSE
DESCRIPTOR.message_types_by_name['ActivatedJob'] = _ACTIVATEDJOB
DESCRIPTOR.message_types_by_name['CancelProcessInstanceRequest'] = _CANCELPROCESSINSTANCEREQUEST
DESCRIPTOR.message_types_by_name['CancelProcessInstanceResponse'] = _CANCELPROCESSINSTANCERESPONSE
DESCRIPTOR.message_types_by_name['CompleteJobRequest'] = _COMPLETEJOBREQUEST
DESCRIPTOR.message_types_by_name['CompleteJobResponse'] = _COMPLETEJOBRESPONSE
DESCRIPTOR.message_types_by_name['CreateProcessInstanceRequest'] = _CREATEPROCESSINSTANCEREQUEST
DESCRIPTOR.message_types_by_name['CreateProcessInstanceResponse'] = _CREATEPROCESSINSTANCERESPONSE
DESCRIPTOR.message_types_by_name['CreateProcessInstanceWithResultRequest'] = _CREATEPROCESSINSTANCEWITHRESULTREQUEST
DESCRIPTOR.message_types_by_name['CreateProcessInstanceWithResultResponse'] = _CREATEPROCESSINSTANCEWITHRESULTRESPONSE
DESCRIPTOR.message_types_by_name['DeployProcessRequest'] = _DEPLOYPROCESSREQUEST
DESCRIPTOR.message_types_by_name['ProcessRequestObject'] = _PROCESSREQUESTOBJECT
DESCRIPTOR.message_types_by_name['DeployProcessResponse'] = _DEPLOYPROCESSRESPONSE
DESCRIPTOR.message_types_by_name['ProcessMetadata'] = _PROCESSMETADATA
DESCRIPTOR.message_types_by_name['FailJobRequest'] = _FAILJOBREQUEST
DESCRIPTOR.message_types_by_name['FailJobResponse'] = _FAILJOBRESPONSE
DESCRIPTOR.message_types_by_name['ThrowErrorRequest'] = _THROWERRORREQUEST
DESCRIPTOR.message_types_by_name['ThrowErrorResponse'] = _THROWERRORRESPONSE
DESCRIPTOR.message_types_by_name['PublishMessageRequest'] = _PUBLISHMESSAGEREQUEST
DESCRIPTOR.message_types_by_name['PublishMessageResponse'] = _PUBLISHMESSAGERESPONSE
DESCRIPTOR.message_types_by_name['ResolveIncidentRequest'] = _RESOLVEINCIDENTREQUEST
DESCRIPTOR.message_types_by_name['ResolveIncidentResponse'] = _RESOLVEINCIDENTRESPONSE
DESCRIPTOR.message_types_by_name['TopologyRequest'] = _TOPOLOGYREQUEST
DESCRIPTOR.message_types_by_name['TopologyResponse'] = _TOPOLOGYRESPONSE
DESCRIPTOR.message_types_by_name['BrokerInfo'] = _BROKERINFO
DESCRIPTOR.message_types_by_name['Partition'] = _PARTITION
DESCRIPTOR.message_types_by_name['UpdateJobRetriesRequest'] = _UPDATEJOBRETRIESREQUEST
DESCRIPTOR.message_types_by_name['UpdateJobRetriesResponse'] = _UPDATEJOBRETRIESRESPONSE
DESCRIPTOR.message_types_by_name['SetVariablesRequest'] = _SETVARIABLESREQUEST
DESCRIPTOR.message_types_by_name['SetVariablesResponse'] = _SETVARIABLESRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ActivateJobsRequest = _reflection.GeneratedProtocolMessageType('ActivateJobsRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVATEJOBSREQUEST,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.ActivateJobsRequest)
  })
_sym_db.RegisterMessage(ActivateJobsRequest)

ActivateJobsResponse = _reflection.GeneratedProtocolMessageType('ActivateJobsResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVATEJOBSRESPONSE,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.ActivateJobsResponse)
  })
_sym_db.RegisterMessage(ActivateJobsResponse)

ActivatedJob = _reflection.GeneratedProtocolMessageType('ActivatedJob', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVATEDJOB,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.ActivatedJob)
  })
_sym_db.RegisterMessage(ActivatedJob)

CancelProcessInstanceRequest = _reflection.GeneratedProtocolMessageType('CancelProcessInstanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _CANCELPROCESSINSTANCEREQUEST,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.CancelProcessInstanceRequest)
  })
_sym_db.RegisterMessage(CancelProcessInstanceRequest)

CancelProcessInstanceResponse = _reflection.GeneratedProtocolMessageType('CancelProcessInstanceResponse', (_message.Message,), {
  'DESCRIPTOR' : _CANCELPROCESSINSTANCERESPONSE,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.CancelProcessInstanceResponse)
  })
_sym_db.RegisterMessage(CancelProcessInstanceResponse)

CompleteJobRequest = _reflection.GeneratedProtocolMessageType('CompleteJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _COMPLETEJOBREQUEST,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.CompleteJobRequest)
  })
_sym_db.RegisterMessage(CompleteJobRequest)

CompleteJobResponse = _reflection.GeneratedProtocolMessageType('CompleteJobResponse', (_message.Message,), {
  'DESCRIPTOR' : _COMPLETEJOBRESPONSE,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.CompleteJobResponse)
  })
_sym_db.RegisterMessage(CompleteJobResponse)

CreateProcessInstanceRequest = _reflection.GeneratedProtocolMessageType('CreateProcessInstanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPROCESSINSTANCEREQUEST,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.CreateProcessInstanceRequest)
  })
_sym_db.RegisterMessage(CreateProcessInstanceRequest)

CreateProcessInstanceResponse = _reflection.GeneratedProtocolMessageType('CreateProcessInstanceResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPROCESSINSTANCERESPONSE,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.CreateProcessInstanceResponse)
  })
_sym_db.RegisterMessage(CreateProcessInstanceResponse)

CreateProcessInstanceWithResultRequest = _reflection.GeneratedProtocolMessageType('CreateProcessInstanceWithResultRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPROCESSINSTANCEWITHRESULTREQUEST,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.CreateProcessInstanceWithResultRequest)
  })
_sym_db.RegisterMessage(CreateProcessInstanceWithResultRequest)

CreateProcessInstanceWithResultResponse = _reflection.GeneratedProtocolMessageType('CreateProcessInstanceWithResultResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPROCESSINSTANCEWITHRESULTRESPONSE,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.CreateProcessInstanceWithResultResponse)
  })
_sym_db.RegisterMessage(CreateProcessInstanceWithResultResponse)

DeployProcessRequest = _reflection.GeneratedProtocolMessageType('DeployProcessRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEPLOYPROCESSREQUEST,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.DeployProcessRequest)
  })
_sym_db.RegisterMessage(DeployProcessRequest)

ProcessRequestObject = _reflection.GeneratedProtocolMessageType('ProcessRequestObject', (_message.Message,), {
  'DESCRIPTOR' : _PROCESSREQUESTOBJECT,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.ProcessRequestObject)
  })
_sym_db.RegisterMessage(ProcessRequestObject)

DeployProcessResponse = _reflection.GeneratedProtocolMessageType('DeployProcessResponse', (_message.Message,), {
  'DESCRIPTOR' : _DEPLOYPROCESSRESPONSE,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.DeployProcessResponse)
  })
_sym_db.RegisterMessage(DeployProcessResponse)

ProcessMetadata = _reflection.GeneratedProtocolMessageType('ProcessMetadata', (_message.Message,), {
  'DESCRIPTOR' : _PROCESSMETADATA,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.ProcessMetadata)
  })
_sym_db.RegisterMessage(ProcessMetadata)

FailJobRequest = _reflection.GeneratedProtocolMessageType('FailJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _FAILJOBREQUEST,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.FailJobRequest)
  })
_sym_db.RegisterMessage(FailJobRequest)

FailJobResponse = _reflection.GeneratedProtocolMessageType('FailJobResponse', (_message.Message,), {
  'DESCRIPTOR' : _FAILJOBRESPONSE,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.FailJobResponse)
  })
_sym_db.RegisterMessage(FailJobResponse)

ThrowErrorRequest = _reflection.GeneratedProtocolMessageType('ThrowErrorRequest', (_message.Message,), {
  'DESCRIPTOR' : _THROWERRORREQUEST,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.ThrowErrorRequest)
  })
_sym_db.RegisterMessage(ThrowErrorRequest)

ThrowErrorResponse = _reflection.GeneratedProtocolMessageType('ThrowErrorResponse', (_message.Message,), {
  'DESCRIPTOR' : _THROWERRORRESPONSE,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.ThrowErrorResponse)
  })
_sym_db.RegisterMessage(ThrowErrorResponse)

PublishMessageRequest = _reflection.GeneratedProtocolMessageType('PublishMessageRequest', (_message.Message,), {
  'DESCRIPTOR' : _PUBLISHMESSAGEREQUEST,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.PublishMessageRequest)
  })
_sym_db.RegisterMessage(PublishMessageRequest)

PublishMessageResponse = _reflection.GeneratedProtocolMessageType('PublishMessageResponse', (_message.Message,), {
  'DESCRIPTOR' : _PUBLISHMESSAGERESPONSE,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.PublishMessageResponse)
  })
_sym_db.RegisterMessage(PublishMessageResponse)

ResolveIncidentRequest = _reflection.GeneratedProtocolMessageType('ResolveIncidentRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESOLVEINCIDENTREQUEST,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.ResolveIncidentRequest)
  })
_sym_db.RegisterMessage(ResolveIncidentRequest)

ResolveIncidentResponse = _reflection.GeneratedProtocolMessageType('ResolveIncidentResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESOLVEINCIDENTRESPONSE,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.ResolveIncidentResponse)
  })
_sym_db.RegisterMessage(ResolveIncidentResponse)

TopologyRequest = _reflection.GeneratedProtocolMessageType('TopologyRequest', (_message.Message,), {
  'DESCRIPTOR' : _TOPOLOGYREQUEST,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.TopologyRequest)
  })
_sym_db.RegisterMessage(TopologyRequest)

TopologyResponse = _reflection.GeneratedProtocolMessageType('TopologyResponse', (_message.Message,), {
  'DESCRIPTOR' : _TOPOLOGYRESPONSE,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.TopologyResponse)
  })
_sym_db.RegisterMessage(TopologyResponse)

BrokerInfo = _reflection.GeneratedProtocolMessageType('BrokerInfo', (_message.Message,), {
  'DESCRIPTOR' : _BROKERINFO,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.BrokerInfo)
  })
_sym_db.RegisterMessage(BrokerInfo)

Partition = _reflection.GeneratedProtocolMessageType('Partition', (_message.Message,), {
  'DESCRIPTOR' : _PARTITION,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.Partition)
  })
_sym_db.RegisterMessage(Partition)

UpdateJobRetriesRequest = _reflection.GeneratedProtocolMessageType('UpdateJobRetriesRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEJOBRETRIESREQUEST,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.UpdateJobRetriesRequest)
  })
_sym_db.RegisterMessage(UpdateJobRetriesRequest)

UpdateJobRetriesResponse = _reflection.GeneratedProtocolMessageType('UpdateJobRetriesResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEJOBRETRIESRESPONSE,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.UpdateJobRetriesResponse)
  })
_sym_db.RegisterMessage(UpdateJobRetriesResponse)

SetVariablesRequest = _reflection.GeneratedProtocolMessageType('SetVariablesRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETVARIABLESREQUEST,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.SetVariablesRequest)
  })
_sym_db.RegisterMessage(SetVariablesRequest)

SetVariablesResponse = _reflection.GeneratedProtocolMessageType('SetVariablesResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETVARIABLESRESPONSE,
  '__module__' : 'zeebe_grpc.gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway_protocol.SetVariablesResponse)
  })
_sym_db.RegisterMessage(SetVariablesResponse)


DESCRIPTOR._options = None

_GATEWAY = _descriptor.ServiceDescriptor(
  name='Gateway',
  full_name='gateway_protocol.Gateway',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2905,
  serialized_end=4283,
  methods=[
  _descriptor.MethodDescriptor(
    name='ActivateJobs',
    full_name='gateway_protocol.Gateway.ActivateJobs',
    index=0,
    containing_service=None,
    input_type=_ACTIVATEJOBSREQUEST,
    output_type=_ACTIVATEJOBSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CancelProcessInstance',
    full_name='gateway_protocol.Gateway.CancelProcessInstance',
    index=1,
    containing_service=None,
    input_type=_CANCELPROCESSINSTANCEREQUEST,
    output_type=_CANCELPROCESSINSTANCERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CompleteJob',
    full_name='gateway_protocol.Gateway.CompleteJob',
    index=2,
    containing_service=None,
    input_type=_COMPLETEJOBREQUEST,
    output_type=_COMPLETEJOBRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateProcessInstance',
    full_name='gateway_protocol.Gateway.CreateProcessInstance',
    index=3,
    containing_service=None,
    input_type=_CREATEPROCESSINSTANCEREQUEST,
    output_type=_CREATEPROCESSINSTANCERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateProcessInstanceWithResult',
    full_name='gateway_protocol.Gateway.CreateProcessInstanceWithResult',
    index=4,
    containing_service=None,
    input_type=_CREATEPROCESSINSTANCEWITHRESULTREQUEST,
    output_type=_CREATEPROCESSINSTANCEWITHRESULTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeployProcess',
    full_name='gateway_protocol.Gateway.DeployProcess',
    index=5,
    containing_service=None,
    input_type=_DEPLOYPROCESSREQUEST,
    output_type=_DEPLOYPROCESSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FailJob',
    full_name='gateway_protocol.Gateway.FailJob',
    index=6,
    containing_service=None,
    input_type=_FAILJOBREQUEST,
    output_type=_FAILJOBRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ThrowError',
    full_name='gateway_protocol.Gateway.ThrowError',
    index=7,
    containing_service=None,
    input_type=_THROWERRORREQUEST,
    output_type=_THROWERRORRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PublishMessage',
    full_name='gateway_protocol.Gateway.PublishMessage',
    index=8,
    containing_service=None,
    input_type=_PUBLISHMESSAGEREQUEST,
    output_type=_PUBLISHMESSAGERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ResolveIncident',
    full_name='gateway_protocol.Gateway.ResolveIncident',
    index=9,
    containing_service=None,
    input_type=_RESOLVEINCIDENTREQUEST,
    output_type=_RESOLVEINCIDENTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetVariables',
    full_name='gateway_protocol.Gateway.SetVariables',
    index=10,
    containing_service=None,
    input_type=_SETVARIABLESREQUEST,
    output_type=_SETVARIABLESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Topology',
    full_name='gateway_protocol.Gateway.Topology',
    index=11,
    containing_service=None,
    input_type=_TOPOLOGYREQUEST,
    output_type=_TOPOLOGYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateJobRetries',
    full_name='gateway_protocol.Gateway.UpdateJobRetries',
    index=12,
    containing_service=None,
    input_type=_UPDATEJOBRETRIESREQUEST,
    output_type=_UPDATEJOBRETRIESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_GATEWAY)

DESCRIPTOR.services_by_name['Gateway'] = _GATEWAY

# @@protoc_insertion_point(module_scope)
